/*  aqotdd - Afghan's Quote of the day server - An RFC865 compliant server.
    Copyright (C) 2000 Afghan Hound Software

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA*/

/* logging.c - Handles logging messages to stderr/syslog/logfile. (opening log
   file is in daemon.c - need to open file *before* dropping root    */

#include "main.h"
/* Note that messages are trucated to < 1024 bytes to avoid problems
   with finding vnsprintf on solaris */

#define MAX_LOG_MSG  2048


void log_message(int level,char *format,...)
{
  va_list argp;
  char buffer[MAX_LOG_MSG];
  struct tm *c;
  time_t    now;
  

  va_start(argp,format);
  (void)vsprintf(buffer,format,argp);
  va_end(argp);
  if ((use_sys)&&(!debug_flag))
    {
#if HAVE_SYSLOG_H
      syslog(level,"[%d]:%s\n",(int)getpid(),buffer);
#endif
    }
  else
    {
      now = time(NULL);
      c = localtime(&now);
      c->tm_year += 1900; /* WFT? */
      if (log_fileh!=NULL)
	{
	  fprintf(log_fileh,"%02d/%02d/%04d %02d:%02d:%02d [%d] %s",c->tm_mday,c->tm_mon,c->tm_year,c->tm_hour,c->tm_min,c->tm_sec,(int)getpid(),buffer);
	}
      else
	{
	  fprintf(stderr,"%02d/%02d/%04d %02d:%02d:%02d [%d] %s",c->tm_mday,c->tm_mon,c->tm_year,c->tm_hour,c->tm_min,c->tm_sec,(int)getpid(),buffer);
	}
    }
}


/* We're ready to go */
void log_printready()
{
  if ((use_tcp)&&(use_udp))
    {
      log_message(LOG_INFO,"Afghan QOTD Server Version %s(%s) compiled at %s, on %s, ready. Listening on tcp/%d, udp/%d.\n",VERSION,NAME,__TIME__,__DATE__,real_tcp_port,real_udp_port);
      return;
    }
  if (use_tcp)
    {
      log_message(LOG_INFO,"Afghan QOTD Server Version %s(%s) ready. Listening on tcp/%d.\n",VERSION,NAME,real_tcp_port);
      return;
    }
  if (use_udp)
    {
      log_message(LOG_INFO,"Afghan QOTD Server Version %s(%s) ready. Listening on udp/%d.\n",VERSION,NAME,real_udp_port);
      return;
    }  
}

/* Passes msg1,msg2 to log. (Using 2 so msg2 can be (strerror(errno)), etc)*/
/* Exits after ERRFAIL, ERRFILEF, ERRMEM - unrecoverable errors            */
void my_message(int type,char *msg1,char *msg2)
{
  if ((type==MSG_ERRFAIL)||(type==MSG_ERRFILEF))
    {
      log_message(LOG_CRIT,"%s %s\n",msg1,msg2);
      exit(1);
    }
  if (type<=log_msg)
    {
      log_message(LOG_INFO,"%s %s\n",msg1,msg2);
    }
}
